package org.processmining.plugins.cosa;

import java.io.IOException;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

import org.processmining.models.graphbased.directed.petrinet.PetrinetGraph;
import org.processmining.models.graphbased.directed.petrinet.elements.ExpandableSubNet;
import org.processmining.models.graphbased.directed.petrinet.elements.Place;

/**
 * @author hverbeek
 * 
 *         CONDITION ::= token [COORDINATE] ("icon_id" ICONID | "type" TYPE)*
 *         "end" ["condition"] ["declare"]
 */
public class CosaCondition extends CosaElement {

	private String name;
	private CosaCoordinate coordinate;
	private final List<CosaIconId> iconIdList;
	private final List<CosaType> typeList;

	public CosaCondition() {
		name = null;
		coordinate = null;
		iconIdList = new ArrayList<CosaIconId>();
		typeList = new ArrayList<CosaType>();
	}

	public void parse(CosaStream input) throws IOException {
		if (input.getToken().equals("condition")) {
			input.advance();
		}
		name = input.getToken();
		input.advance();
		if (!input.getToken().equals("icon_id")) {
			coordinate = new CosaCoordinate();
			coordinate.parse(input);
		}
		while (!input.getToken().equals("end")) {
			if (input.getToken().equals("icon_id")) {
				input.advance();
				CosaIconId iconId = new CosaIconId();
				iconId.parse(input);
				iconIdList.add(iconId);
			} else if (input.getToken().equals("type")) {
				input.advance();
				CosaType type = new CosaType();
				type.parse(input);
				typeList.add(type);
			}
		}
		input.advance();
		if (input.getToken().equals("condition")) {
			input.advance();
		}
		if (input.getToken().equals("declare")) {
			input.advance();
		}
	}

	public String getName() {
		return name;
	}

	public void convertToNet(PetrinetGraph net, ExpandableSubNet subnet, Map<String, Place> placeMap) {
		placeMap.put(name, net.addPlace(name, subnet));
	}
}
