package org.processmining.plugins.cosa;

import java.io.IOException;
import java.util.Map;

import org.processmining.models.graphbased.directed.petrinet.PetrinetGraph;
import org.processmining.models.graphbased.directed.petrinet.elements.ExpandableSubNet;
import org.processmining.models.graphbased.directed.petrinet.elements.Place;
import org.processmining.models.graphbased.directed.petrinet.elements.Transition;

/**
 * @author hverbeek
 * 
 *         CONNECTION ::= token ["predicate" token]
 */
public class CosaConnection extends CosaElement {

	private String conditionName;
	private String predicate;

	public CosaConnection() {
		conditionName = null;
		predicate = null;
	}

	public void parse(CosaStream input) throws IOException {
		conditionName = input.getToken();
		input.advance();
		if (input.getToken().equals("predicate")) {
			input.advance();
			predicate = input.getToken();
			input.advance();
		}
	}

	public void convertInputToNet(PetrinetGraph net, ExpandableSubNet subnet, Transition transition,
			Map<String, Place> placeMap) {
		net.addArc(placeMap.get(conditionName), transition, subnet);
	}

	public void convertOutputToNet(PetrinetGraph net, ExpandableSubNet subnet, Transition transition,
			Map<String, Place> placeMap) {
		net.addArc(transition, placeMap.get(conditionName), subnet);
	}

	public boolean hasPredicate() {
		return predicate != null;
	}

	public String getName() {
		return conditionName;
	}
}
