package org.processmining.plugins.cosa;

import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

/**
 * @author hverbeek
 * 
 *         PROCESS ::= token token ["undo_process_begin" token*
 *         "undo_process_end"]
 */
public class CosaProcess extends CosaElement {

	private String commandString;
	private String commandType;
	private final List<String> undoList;

	public CosaProcess() {
		commandString = null;
		commandType = null;
		undoList = new ArrayList<String>();
	}

	public void parse(CosaStream input) throws IOException {
		commandString = input.getToken();
		input.advance();
		commandType = input.getToken();
		input.advance();
		if (input.getToken().equals("undo_process_begin")) {
			input.advance();
			while (!input.getToken().equals("undo_process_end")) {
				undoList.add(input.getToken());
				input.advance();
			}
			input.advance();
		}
	}

	public CosaBehavior getJoinBehavior() {
		if (commandType.equals("analysis")) {
			if (commandString.equalsIgnoreCase("and-join") || commandString.equalsIgnoreCase("and_join")) {
				return CosaBehavior.AND;
			} else if (commandString.equalsIgnoreCase("xor-join") || commandString.equalsIgnoreCase("xor_join")) {
				return CosaBehavior.XOR;
			} else if (commandString.equalsIgnoreCase("or-join") || commandString.equalsIgnoreCase("or_join")) {
				return CosaBehavior.OR;
			}
		}
		return CosaBehavior.NN;
	}

	public CosaBehavior getSplitBehavior() {
		if (commandType.equals("analysis")) {
			if (commandString.equalsIgnoreCase("and-split") || commandString.equalsIgnoreCase("and_split")) {
				return CosaBehavior.AND;
			} else if (commandString.equalsIgnoreCase("xor-split") || commandString.equalsIgnoreCase("xor_split")) {
				return CosaBehavior.XOR;
			} else if (commandString.equalsIgnoreCase("or-split") || commandString.equalsIgnoreCase("or_split")) {
				return CosaBehavior.OR;
			}
		}
		return CosaBehavior.NN;
	}
}
