package org.processmining.plugins.cosa;

import java.io.IOException;
import java.util.HashMap;
import java.util.Map;

import org.processmining.models.graphbased.directed.petrinet.PetrinetGraph;
import org.processmining.models.graphbased.directed.petrinet.elements.ExpandableSubNet;
import org.processmining.models.graphbased.directed.petrinet.elements.Place;
import org.processmining.models.semantics.petrinet.Marking;

/**
 * @author hverbeek
 * 
 *         SCRIPT ::= ["declare"] ["flow"] FLOW
 */
public class CosaScript extends CosaElement {

	private CosaFlow flow;

	public CosaScript() {
		flow = null;
	}

	/*
	 * Parse this script, given the parent script (null if root script) and path
	 * to folder where root script resides.
	 */
	public void parse(CosaStream input, CosaScript parent, String path) throws IOException {
		if (input.getToken().equals("declare")) {
			input.advance();
		}
		if (input.getToken().equals("flow")) {
			input.advance();
		}
		flow = new CosaFlow();
		flow.parse(input, parent, this, path);
	}

	public String getName() {
		return flow.getName();
	}

	/*
	 * Convert this script into a net and a marking. This method should only be
	 * invoked for the root script.
	 */
	public void convertToNet(PetrinetGraph net, ExpandableSubNet subnet, Marking marking) {
		Place startPlace = net.addPlace("start flow");
		Place endPlace = net.addPlace("end flow");
		marking.add(startPlace);
		convertToNet(net, subnet, startPlace, endPlace);
	}

	/*
	 * Convert this script into a net, given the net's source place and sink
	 * place.
	 */
	public void convertToNet(PetrinetGraph net, ExpandableSubNet subnet, Place startPlace, Place endPlace) {
		Map<String, Place> placeMap = new HashMap<String, Place>();
		flow.convertToNet(net, subnet, startPlace, endPlace, placeMap);
	}
}
