package org.processmining.plugins.cosa;

import java.io.IOException;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collection;
import java.util.List;

/**
 * @author hverbeek
 * 
 *         WITH ::= ( "with" | "no_reroute" | "no_priority_change" | "no_undo" |
 *         "no_delegate" | "no_redistribute" | "no_reserve" )* ["icond_id"
 *         ICONID] ["duration" DURATION]
 */
public class CosaWith extends CosaElement {

	private final List<String> skipList;
	private final List<String> noRerouteList;
	private final List<String> noPriorityChangeList;
	private final List<String> noUndoList;
	private final List<String> noDelegateList;
	private final List<String> noRedistributeList;
	private final List<String> noReserveList;
	private CosaIconId iconId;
	private CosaDuration duration;

	public CosaWith() {
		skipList = new ArrayList<String>();
		noRerouteList = new ArrayList<String>();
		noPriorityChangeList = new ArrayList<String>();
		noUndoList = new ArrayList<String>();
		noDelegateList = new ArrayList<String>();
		noRedistributeList = new ArrayList<String>();
		noReserveList = new ArrayList<String>();
		iconId = null;
		duration = null;
	}

	public void parse(CosaStream input) throws IOException {
		Collection<String> withKeywords = new ArrayList<String>(Arrays.asList("skip", "no_reroute",
				"no_priority_change", "no_undo", "no_delegate", "no_redistribute", "no_reserve"));
		while (withKeywords.contains(input.getToken())) {
			if (input.getToken().equals("skip")) {
				skipList.add(input.getToken());
			}
			if (input.getToken().equals("no_reroute")) {
				noRerouteList.add(input.getToken());
			}
			if (input.getToken().equals("no_priority_change")) {
				noPriorityChangeList.add(input.getToken());
			}
			if (input.getToken().equals("no_undo")) {
				noUndoList.add(input.getToken());
			}
			if (input.getToken().equals("no_delegate")) {
				noDelegateList.add(input.getToken());
			}
			if (input.getToken().equals("no_redistribute")) {
				noRedistributeList.add(input.getToken());
			}
			if (input.getToken().equals("no_reserve")) {
				noReserveList.add(input.getToken());
			}
			input.advance();
		}
		if (input.getToken().equals("icon_id")) {
			input.advance();
			iconId = new CosaIconId();
			iconId.parse(input);
		}
		if (input.getToken().equals("duration")) {
			input.advance();
			duration = new CosaDuration();
			duration.parse(input);
		}
	}
}
